package com.zyc.system.mapper;

import java.util.List;
import com.zyc.system.domain.Devices;

/**
 * 设备基本信息Mapper接口
 * 
 * @author zyc
 * @date 2024-12-26
 */
public interface DevicesMapper 
{
    /**
     * 查询设备基本信息
     * 
     * @param id 设备基本信息主键
     * @return 设备基本信息
     */
    public Devices selectDevicesById(Integer id);

    /**
     * 查询设备基本信息列表
     * 
     * @param devices 设备基本信息
     * @return 设备基本信息集合
     */
    public List<Devices> selectDevicesList(Devices devices);

    /**
     * 新增设备基本信息
     * 
     * @param devices 设备基本信息
     * @return 结果
     */
    public int insertDevices(Devices devices);

    /**
     * 修改设备基本信息
     * 
     * @param devices 设备基本信息
     * @return 结果
     */
    public int updateDevices(Devices devices);

    /**
     * 删除设备基本信息
     * 
     * @param id 设备基本信息主键
     * @return 结果
     */
    public int deleteDevicesById(Integer id);

    /**
     * 批量删除设备基本信息
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteDevicesByIds(Integer[] ids);
}
